\name{mplayer}
\alias{mplayer}
\alias{run.mplayer}
\title{
  Mplayer interface
}
\description{
  \code{mplayer} sets up an interface to mplayer for analyzing frames

  \code{run.mplayer} runs mplayer
}
\usage{
mplayer(FUN=update.display, setup.FUN=new.display,
        format="RGB24", expand=TRUE, port=7922, save.env=NULL)
run.mplayer(file)
}
\arguments{
  \item{FUN}{function to call for each frame}
  \item{setup.FUN}{function to call before first frame (or NULL if not needed)}
  \item{format}{format to use for decoded frames (fourcc integer value
    or string)}
  \item{expand}{for 4:1:1 formats whether to expand chroma matrices to
    full size}
  \item{port}{port to listen on}
  \item{save.env}{store internal results to the environment (for
    debugging only)}
  \item{file}{file to play back using videTools vo}
}
\value{
  \code{TRUE}
}
\details{
  \code{mplayer} creates a server that listens in anticipation of a
  connection from the videoTools mplayer module. Once connection is
  established, \code{setup.FUN} is called as \code{setup.FUN(width,
    height)} with the frame dimensions. Then each frame received from
  mplayer is decoded and stored in matrix form according to the format
  used. This matrix form is then passed for the \code{FUN}
  function. Depending on the format the calls are as follows:

  \code{RGB} or \code{BGR}: \code{FUN(r, g, b)}

  \code{YV12} (4:1:1): \code{FUN(Y, U, V)}

  \code{YUY2} (4:2:2): \code{FUN(Y, UV)}

  where \code{r}, \code{g}, \code{b} and \code{Y} are width*height
  matrices, \code{U} (aka Cb) and \code{V} (aka Cr) are width/2*height/2
  matrices (unless \code{expand=TRUE}). \code{UV} is a width*height
  matrix with horizontally interlaced \code{U} and \code{V} (thus
  \code{U=UV[1:(dim(U)[1]/2-1)*2-1,]})
  
  Other formats can be used, but they are not decoded to matrix
  form. (Note that \code{I420}=\code{IYUV} and is the same as
  \code{YV12} except for the order of \code{U} and \code{V}. Also
  \code{YUYV}=\code{YUY2})

  Note: All values (including \code{Y}, \code{U} and \code{V}) are
  expanded based on the full 0-255 range of each byte. Correction of
  actually used ranges is currently not performed, but may possibly be
  at a later point.

  \code{run.mplayer} runs the mplayer with correct arguments to connect
  to a local videoTools server. Please note that you cannot run both
  mplayer and the analysis in the same R. You must first call the
  \code{mplayer()} function in R and only then start mplayer from
  another terminal (or another R). Unfortunately mplayer cannot be
  compiled as a library (it doesn't support PIC compilation), so we
  cannot plug it directly into R.
}
%\seealso{
%}
\examples{
\dontrun{
mplayer()
}
}
\keyword{interface}
